The approach followed in cplm_ic in order to detect the
change-points is based on identifying the set of change-points that minimise an
information criterion. At first, we employ sol_path_cplm, which
overestimates the number of change-points using th_const in order to define the
threshold and then sorts the obtained estimates in a way that the estimate,
which is most likely to be correct appears first, whereas the least likely
to be correct, appears last. Let \(J\) be the number of estimates
that this overestimation approach returns. We will obtain a vector
\(b = (b_1, b_2, ..., b_J)\), with the estimates ordered as explained above. We
define the collection \(\left\{M_j\right\}_{j = 0,1,\ldots,J}\), where \(M_0\)
is the empty set and \(M_j = \left\{b_1,b_2,...,b_j\right\}\). Among the collection
of models \(M_j, j=0,1,...,J\), we select the one that minimises a predefined
Information Criterion. The obtained set of change-points is apparently a subset of
the solution path given in sol_path_cplm. More details can be found
in ``Detecting multiple generalized change-points by isolating single ones'',
Anastasiou and Fryzlewicz (2018), preprint.