cpt_ic_pcm: Multiple change-point detection in the mean via minimising an...

View source: R/Finalised_coding.R

cpt_ic_pcmR Documentation

Multiple change-point detection in the mean via minimising an information criterion

Description

This function performs the Isolate-Detect methodology based on an information criterion approach, in order to detect multiple change-points in the mean of a given data sequence. The relevant literature reference is given in details.

Usage

cpt_ic_pcm(
  x,
  th_const = 0.9,
  Kmax = 200,
  penalty = c("ssic_pen", "sic_pen"),
  points = 10
)

Arguments

x

A numeric vector containing the data in which you would like to find change-points.

th_const

A positive real number with default value equal to 0.9. It is used to define the threshold value that will be used at the first step of the model selection based Isolate-Detect method.

Kmax

A positive integer with default value equal to 200. It defines the maximum number of change-points allowed to be detected. In addition, it is the maximum allowed number of estimated change-points in the solution path.

penalty

A character vector with names of penalty functions used.

points

A positive integer with default value equal to 10. It defines the distance between two consecutive end- or start-points of the right- or left-expanding intervals, respectively.

Details

The approach followed in cpt_ic_pcm in order to detect the change-points is based on identifying the set of change-point that minimise an information criterion. The obtained set of change-points is a subset of the solution path, which is given by sol_path_pcm. More details can be found in “Detecting multiple generalized change-points by isolating single ones”, Anastasiou and Fryzlewicz (2017), preprint.

Value

A list with the following components:

sol_path A vector containing the solution path.

ic_curve A list with values of the chosen information criteria.

cpt_ic A list with the change-points detected for each information criterion considered.

no_cpt_ic The number of change-points detected for each information criterion considered.

Author(s)

Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy

See Also

ID_pcm and ID, which employ this function. In addition, see cpt_ic_plm for the case of detecting changes in the slope of a piecewise-linear and continuous signal using the information criterion based approach.

Examples

single.cpt <- c(rep(4,1000),rep(0,1000))
single.cpt.noise <- single.cpt + rnorm(2000)
cpt.single.ic <- cpt_ic_pcm(single.cpt.noise)

three.cpt <- c(rep(4,500),rep(0,500),rep(-4,500),rep(1,500))
three.cpt.noise <- three.cpt + rnorm(2000)
cpt.three.ic <- cpt_ic_pcm(three.cpt.noise)

IDetect documentation built on May 7, 2026, 5:09 p.m.