View source: R/Finalised_coding.R
| normalise | R Documentation |
This function pre-processes the given data in order to obtain a noise structure that is closer to satisfying the Gaussianity assumption. See details for more information and for the relevant literature reference.
normalise(x, sc = 3)
x |
A numeric vector containing the data. |
sc |
A positive integer number with default value equal to 3. It is used to define the way we pre-average the given data sequence. |
For a given natural number sc and data x of length T, let us
denote by Q = \lceil T/sc \rceil. Then, normalise calculates
\tilde{x}_q = 1/sc\sum_{t=(q-1) * sc + 1}^{q * sc}x_t,
for q=1, 2, ..., Q-1, while
\tilde{x}_Q = (T - (Q-1) * sc)^{-1}\sum_{t = (Q-1) * sc + 1}^{T}x_t.
More details can be found in the preprint “Detecting multiple generalized change-points by isolating single ones”, Anastasiou and Fryzlewicz (2017).
The “normalised” vector \tilde{x} of length Q, as explained in Details.
Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy
ht_ID_pcm, ht_ID_plm, and ID, which are
functions that employ normalise.
t5 <- rt(n = 10000, df = 5)
n5 <- normalise(t5, sc = 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.