s_e_points: Derives a subset of integers from a given set

View source: R/Finalised_coding.R

s_e_pointsR Documentation

Derives a subset of integers from a given set

Description

This function finds two subsets of integers in a given interval [s,e]. The routine is typically not called directly by the user; its result is used in order to construct the expanding intervals, where the Isolate-Detect method is going to be applied.

Usage

s_e_points(r, l, s, e)

Arguments

r

A positive integer vector containing the set, from which the end-points of the expanding intervals are to be chosen.

l

A positive integer vector containing the set, from which the start-points of the expanding intervals are to be chosen.

s

A positive integer indicating the starting position, in that we will choose the elements from r and l that are greater than s.

e

A positive integer indicating the finishing position, in that we will choose the elements from r and l that are less than e.

Value

e_points A vector containing the points that will be used as end-points, in order to create the left-expanding intervals. It consists of the input e and all the elements in the input vector r that are in (s,e).

s_points A vector containing the points that will be used as start-points, in order to create the left-expanding intervals. It consists of the input s and all the elements in the input vector l that are in (s,e)

Author(s)

Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy

Examples

s_e_points(r = seq(10,1000,10), l = seq(991,1,-10), s=435, e = 786)
s_e_points(r = seq(3,100,3), l = seq(98,1,-3), s=43, e = 86)

IDetect documentation built on May 7, 2026, 5:09 p.m.