sic_pen: Schwarz Information Criterion penalty

View source: R/Finalised_coding.R

sic_penR Documentation

Schwarz Information Criterion penalty

Description

This function evaluates the penalty term for the Schwarz Information Criterion. The routine is typically not called directly by the user; its name can be passed as an argument to cpt_ic_pcm and cpt_ic_plm.

Usage

sic_pen(n, n_param)

Arguments

n

The number of observations.

n_param

The number of parameters in the model for which the penalty is evaluated.

Value

The penalty term log(n) * n_param.

Author(s)

Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy

See Also

ssic_pen for the strengthened Schwarz Information Criterion penalty.

Examples

three.cpt <- c(rep(4,400),rep(0,400),rep(-4,400),rep(1,400))
three.cpt.noise <- three.cpt + rnorm(1600)
detected_cpts <- cpt_ic_pcm(three.cpt.noise, penalty = "sic_pen")

IDetect documentation built on May 7, 2026, 5:09 p.m.