sol_path_pcm: The solution path for the case of piecewise-constant mean...

View source: R/Finalised_coding.R

sol_path_pcmR Documentation

The solution path for the case of piecewise-constant mean signals

Description

This function starts by over-estimating the number of true change-points. After that, following a CUSUM-based approach, it sorts the estimated change-points in a way that the estimation, which is most-likely to be correct appears first, whereas the least likely to be correct, appears last. The routine is typically not called directly by the user; it is employed in cpt_ic_pcm.

Usage

sol_path_pcm(x, thr_ic = 0.9, points = 3)

Arguments

x

A numeric vector containing the data in which you would like to find change-points.

thr_ic

A positive real number with default value equal to 0.9. It is used to define the threshold. The change-points are estimated by thresholding with threshold equal to sigma * thr_const * sqrt(2 * log(l)), where l is the length of the data sequence x. Because, we would like to overestimate the number of the true change-points in x, it is suggested to keep thr_ic smaller than 1, which is the default value used as the threshold constant in the function wind_pcm_th.

points

A positive integer with default value equal to 3. It defines the distance between two consecutive end- or start-points of the right- or left-expanding intervals, respectively.

Value

The solution path for the case of piecewise-constant mean signals.

Author(s)

Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy

Examples

three.cpt <- c(rep(4,4000),rep(0,4000),rep(-4,4000),rep(1,4000))
three.cpt.noise <- three.cpt + rnorm(16000)
solution.path <- sol_path_pcm(three.cpt.noise)

IDetect documentation built on May 7, 2026, 5:09 p.m.