sol_path_plm: The solution path for the case of continuous piecewise-linear...

View source: R/Finalised_coding.R

sol_path_plmR Documentation

The solution path for the case of continuous piecewise-linear mean signals

Description

This function starts by over-estimating the number of true change-points. After that, following an approach based on the values of a contrast function, it sorts the estimated change-points in a way that the estimation, which is most-likely to be correct appears first, whereas the least likely to be correct, appears last. The routine is typically not called directly by the user; it is employed in cpt_ic_plm.

Usage

sol_path_plm(x, thr_ic = 1.25, points = 3)

Arguments

x

A numeric vector containing the data in which you would like to find change-points.

thr_ic

A positive real number with default value equal to 1.25. It is used to define the threshold. The change-points are estimated by thresholding with threshold equal to sigma * thr_const * sqrt(2 * log(l)), where l is the length of the data sequence x. Because, we would like to overestimate the number of the true change-points in x, it is suggested to keep thr_ic smaller than 1.4, which is the default value used as the threshold constant in the function wind_plm_th.

points

A positive integer with default value equal to 3. It defines the distance between two consecutive end- or start-points of the right- or left-expanding intervals, respectively.

Value

The solution path for the case of continuous piecewise-linear mean signals.

Author(s)

Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy

Examples

three.cpt <- c(seq(0, 499, 1.2), seq(498.5, 249, -0.5), seq(250.5,999,1.5), seq(998,499,-1))
three.cpt.noise <- three.cpt + rnorm(2000)
solution.path <- sol_path_plm(three.cpt.noise)

IDetect documentation built on May 7, 2026, 5:09 p.m.