ssic_pen: Strengthened Schwarz Information Criterion penalty

View source: R/Finalised_coding.R

ssic_penR Documentation

Strengthened Schwarz Information Criterion penalty

Description

This function evaluates the penalty term for the strengtened Schwarz Information Criterion proposed in Fryzlewicz (2014). The routine is typically not called directly by the user; its name can be passed as an argument to cpt_ic_pcm and cpt_ic_plm.

Usage

ssic_pen(n, n_param, alpha = 1.01)

Arguments

n

The number of observations.

n_param

The number of parameters in the model for which the penalty is evaluated.

alpha

A real number greater than one.

Details

The strengthened Schwarz Information Criterion was introduced in Fryzlewicz (2014). Taking alpha = 1 will give the known Schwarz Information Criterion of sic_pen.

Value

The penalty term log(n)^alpha * n_param.

Author(s)

Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy

References

Fryzlewicz, P. (2014). Wild Binary Segmentation for multiple change-point detection. Annals of Statistics, Vol. 42, No. 6, 2243-2281.

See Also

sic_pen for the Schwarz Information Criterion penalty.

Examples

three.cpt <- c(rep(4,400),rep(0,400),rep(-4,400),rep(1,400))
three.cpt.noise <- three.cpt + rnorm(1600)
detected_cpts <- cpt_ic_pcm(three.cpt.noise, penalty = "ssic_pen")

IDetect documentation built on May 7, 2026, 5:09 p.m.