View source: R/Finalised_coding.R
| sic_pen | R Documentation |
This function evaluates the penalty term for the Schwarz Information Criterion. The
routine is typically not called directly by the user; its name can be passed as an
argument to cpt_ic_pcm and cpt_ic_plm.
sic_pen(n, n_param)
n |
The number of observations. |
n_param |
The number of parameters in the model for which the penalty is evaluated. |
The penalty term log(n) * n_param.
Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy
ssic_pen for the strengthened Schwarz Information Criterion penalty.
three.cpt <- c(rep(4,400),rep(0,400),rep(-4,400),rep(1,400))
three.cpt.noise <- three.cpt + rnorm(1600)
detected_cpts <- cpt_ic_pcm(three.cpt.noise, penalty = "sic_pen")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.