View source: R/Finalised_coding.R
| sol_path_pcm | R Documentation |
This function starts by over-estimating the number of true change-points.
After that, following a CUSUM-based approach, it sorts the estimated change-points
in a way that the estimation, which is most-likely to be correct appears first, whereas
the least likely to be correct, appears last. The routine is typically not called
directly by the user; it is employed in cpt_ic_pcm.
sol_path_pcm(x, thr_ic = 0.9, points = 3)
x |
A numeric vector containing the data in which you would like to find change-points. |
thr_ic |
A positive real number with default value equal to 0.9. It is
used to define the threshold. The change-points are estimated by thresholding
with threshold equal to |
points |
A positive integer with default value equal to 3. It defines the distance between two consecutive end- or start-points of the right- or left-expanding intervals, respectively. |
The solution path for the case of piecewise-constant mean signals.
Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy
three.cpt <- c(rep(4,4000),rep(0,4000),rep(-4,4000),rep(1,4000))
three.cpt.noise <- three.cpt + rnorm(16000)
solution.path <- sol_path_pcm(three.cpt.noise)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.