View source: R/Finalised_coding.R
| sol_path_plm | R Documentation |
This function starts by over-estimating the number of true change-points.
After that, following an approach based on the values of a contrast function,
it sorts the estimated change-points in a way that the estimation, which is
most-likely to be correct appears first, whereas the least likely to be correct,
appears last. The routine is typically not called directly by the user; it is
employed in cpt_ic_plm.
sol_path_plm(x, thr_ic = 1.25, points = 3)
x |
A numeric vector containing the data in which you would like to find change-points. |
thr_ic |
A positive real number with default value equal to 1.25. It is
used to define the threshold. The change-points are estimated by thresholding
with threshold equal to |
points |
A positive integer with default value equal to 3. It defines the distance between two consecutive end- or start-points of the right- or left-expanding intervals, respectively. |
The solution path for the case of continuous piecewise-linear mean signals.
Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy
three.cpt <- c(seq(0, 499, 1.2), seq(498.5, 249, -0.5), seq(250.5,999,1.5), seq(998,499,-1))
three.cpt.noise <- three.cpt + rnorm(2000)
solution.path <- sol_path_plm(three.cpt.noise)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.