View source: R/Finalised_coding.R
| ssic_pen | R Documentation |
This function evaluates the penalty term for the strengtened Schwarz Information Criterion
proposed in Fryzlewicz (2014). The routine is typically not called directly by the user;
its name can be passed as an argument to cpt_ic_pcm and cpt_ic_plm.
ssic_pen(n, n_param, alpha = 1.01)
n |
The number of observations. |
n_param |
The number of parameters in the model for which the penalty is evaluated. |
alpha |
A real number greater than one. |
The strengthened Schwarz Information Criterion was introduced in Fryzlewicz (2014).
Taking alpha = 1 will give the known Schwarz Information Criterion of sic_pen.
The penalty term log(n)^alpha * n_param.
Andreas Anastasiou, anastasiou.andreas@ucy.ac.cy
Fryzlewicz, P. (2014). Wild Binary Segmentation for multiple change-point detection. Annals of Statistics, Vol. 42, No. 6, 2243-2281.
sic_pen for the Schwarz Information Criterion penalty.
three.cpt <- c(rep(4,400),rep(0,400),rep(-4,400),rep(1,400))
three.cpt.noise <- three.cpt + rnorm(1600)
detected_cpts <- cpt_ic_pcm(three.cpt.noise, penalty = "ssic_pen")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.